Class: Aws::TimestreamWrite::Types::CsvConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-timestreamwrite/types.rb

Overview

A delimited data format where the column separator can be a comma and the record separator is a newline character.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#column_separator ⇒ String

Column separator can be one of comma (','), pipe ('|), semicolon (';'), tab('/t'), or blank space (' ').

Returns:

  • (String)


360
361
362
363
364
365
366
367
368
# File 'lib/aws-sdk-timestreamwrite/types.rb', line 360

class CsvConfiguration < Struct.new(
  :column_separator,
  :escape_char,
  :quote_char,
  :null_value,
  :trim_white_space)
  SENSITIVE = []
  include Aws::Structure
end

#escape_char ⇒ String

Escape character can be one of

Returns:

  • (String)


360
361
362
363
364
365
366
367
368
# File 'lib/aws-sdk-timestreamwrite/types.rb', line 360

class CsvConfiguration < Struct.new(
  :column_separator,
  :escape_char,
  :quote_char,
  :null_value,
  :trim_white_space)
  SENSITIVE = []
  include Aws::Structure
end

#null_value ⇒ String

Can be blank space (' ').

Returns:

  • (String)


360
361
362
363
364
365
366
367
368
# File 'lib/aws-sdk-timestreamwrite/types.rb', line 360

class CsvConfiguration < Struct.new(
  :column_separator,
  :escape_char,
  :quote_char,
  :null_value,
  :trim_white_space)
  SENSITIVE = []
  include Aws::Structure
end

#quote_char ⇒ String

Can be single quote (') or double quote (").

Returns:

  • (String)


360
361
362
363
364
365
366
367
368
# File 'lib/aws-sdk-timestreamwrite/types.rb', line 360

class CsvConfiguration < Struct.new(
  :column_separator,
  :escape_char,
  :quote_char,
  :null_value,
  :trim_white_space)
  SENSITIVE = []
  include Aws::Structure
end

#trim_white_space ⇒ Boolean

Specifies to trim leading and trailing white space.

Returns:

  • (Boolean)


360
361
362
363
364
365
366
367
368
# File 'lib/aws-sdk-timestreamwrite/types.rb', line 360

class CsvConfiguration < Struct.new(
  :column_separator,
  :escape_char,
  :quote_char,
  :null_value,
  :trim_white_space)
  SENSITIVE = []
  include Aws::Structure
end